/*
 * Copyright 2006-2020 The MZmine Development Team
 *
 * This file is part of MZmine.
 *
 * MZmine is free software; you can redistribute it and/or modify it under the terms of the GNU
 * General Public License as published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * MZmine is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with MZmine; if not,
 * write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
 * USA
 */

package io.github.mzmine.modules.dataprocessing.filter_baselinecorrection.correctors;

import io.github.mzmine.modules.dataprocessing.filter_baselinecorrection.BaselineCorrectorSetupDialog;
import io.github.mzmine.parameters.UserParameter;
import io.github.mzmine.parameters.impl.SimpleParameterSet;
import io.github.mzmine.parameters.parametertypes.IntegerParameter;
import io.github.mzmine.util.ExitCode;

/**
 * @description Rolling Ball baseline corrector parameters.
 *
 */
public class RollingBallCorrectorParameters extends SimpleParameterSet {

  /**
   * Local minima search window.
   */
  public static final IntegerParameter MIN_MAX_WIDTH = new IntegerParameter("wm (number of scans)",
      "Width of local window for minimization/maximization (in number of scans).", null, 0, null);

  /**
   * Smoothing.
   */
  public static final IntegerParameter SMOOTHING = new IntegerParameter("ws (number of scans)",
      "Width of local window for smoothing (in number of scans).", null, 0, null);

  public RollingBallCorrectorParameters() {
    super(new UserParameter[] {MIN_MAX_WIDTH, SMOOTHING});
  }

  @Override
  public ExitCode showSetupDialog(boolean valueCheckRequired) {
    BaselineCorrectorSetupDialog dialog =
        new BaselineCorrectorSetupDialog(valueCheckRequired, this, RollingBallCorrector.class);
    dialog.showAndWait();
    return dialog.getExitCode();
  }
}
